@@ -29,7 +29,7 @@
 
 #define NUM_FORMAT "%ld"
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 Script::interp::interp() :
 memalloc(Script::paging)
@@ -1380,3 +1380,5 @@ bool Script::interp::getExpression(unsigned index)
 #endif
     return false;
 }
+
+} // namespace ucommon
